"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PropositionPointer = void 0;
const resource_pointer_1 = require("./resource-pointer");
const resource_type_1 = require("./resource-type");
class PropositionPointer {
    constructor(ptr = null, negative = false) {
        this.ptr = ptr;
        this.negative = negative;
    }
    get datasetId() {
        var _a;
        return (_a = this.ptr) === null || _a === void 0 ? void 0 : _a.datasetId;
    }
    static equals(one, two) {
        if (!one || !two) {
            return !one && !two;
        }
        return one.ptr.equals(two.ptr) && one.negative === two.negative;
    }
    static fromResourcePointer(ptr, negative) {
        return new PropositionPointer(ptr, negative);
    }
    static isValid(propPtr) {
        return (resource_pointer_1.ResourcePointer.isValid(propPtr === null || propPtr === void 0 ? void 0 : propPtr.ptr) &&
            (propPtr.ptr.resourceType === resource_type_1.ResourceType.TERM ||
                (propPtr.negative !== null && propPtr.negative !== undefined)));
    }
    static fromStringArr(arr, defaultDatasetId) {
        return arr.map((s) => PropositionPointer.fromString(s, defaultDatasetId));
    }
    static fromString(s, defaultDatasetId) {
        let ptr = null;
        if (s.endsWith(":D") || s.endsWith(":Y") || s.endsWith(":N")) {
            ptr = resource_pointer_1.ResourcePointer.fromString(s.slice(0, -2), defaultDatasetId);
        }
        else {
            ptr = resource_pointer_1.ResourcePointer.fromString(s, defaultDatasetId);
        }
        if (!ptr)
            return null;
        if (ptr.resourceType === resource_type_1.ResourceType.TERM) {
            return new PropositionPointer(ptr, null);
        }
        if (ptr.resourceType === resource_type_1.ResourceType.PROPOSITION) {
            if (s.endsWith(":N")) {
                return new PropositionPointer(ptr, true);
            }
            else {
                return new PropositionPointer(ptr, false);
            }
        }
        return null;
    }
    toString(defaultDatasetId) {
        return this.toStringInternal(false, defaultDatasetId);
    }
    toDisplayString(defaultDatasetId) {
        return this.toStringInternal(true, defaultDatasetId);
    }
    toStringInternal(stripMachineId, defaultDatasetId) {
        let suffix = "";
        if (this.ptr.resourceType === resource_type_1.ResourceType.TERM) {
            suffix = ":D";
        }
        else if (this.negative) {
            suffix = ":N";
        }
        else {
            suffix = ":Y";
        }
        if (!stripMachineId)
            return this.ptr.toString(defaultDatasetId) + suffix;
        else
            return this.ptr.toDisplayString(defaultDatasetId) + suffix;
    }
}
exports.PropositionPointer = PropositionPointer;
