export interface Types {
    argument?: Argument;
    article?: Article;
    beliefset?: Beliefset;
    dataset?: Dataset;
    machine?: Machine;
    page?: Page;
    project?: Project;
    proofRequest?: ProofRequest;
    proofResponse?: ProofResponse;
    proposition?: Proposition;
    resource?: Resource;
    resourceValidity?: ResourceValidity;
    term?: Term;
}
export interface Argument {
    argumentText?: string;
    conclusion?: string;
    language?: Language;
    lookupTerms?: string[];
    metaLanguage?: MetaLanguage;
    premiseMachine?: string;
    premises?: string[];
    assignablePtr?: string;
    citations?: Citation[];
    contributor?: User;
    ephemeralPtr?: string;
    indexable?: boolean;
    names?: string[];
    notPermanentPtr?: string;
    permanentPtr?: string;
    tags?: string[];
}
export interface Citation {
    textCitation?: string;
}
export interface User {
    handle?: string;
    userEmail?: string;
    userLink?: string;
    userName?: string;
    userPic?: string;
}
export declare enum Language {
    Informal = "INFORMAL",
    MetamathSetMm = "METAMATH_SET_MM"
}
export declare enum MetaLanguage {
    Informal = "INFORMAL",
    Metamath = "METAMATH"
}
export interface Article {
    abstractText?: string;
    authors?: Author[];
    beliefset?: string;
    content?: string;
    title?: string;
    assignablePtr?: string;
    citations?: Citation[];
    contributor?: User;
    ephemeralPtr?: string;
    indexable?: boolean;
    names?: string[];
    notPermanentPtr?: string;
    permanentPtr?: string;
    tags?: string[];
}
export interface Author {
    user?: User;
}
export interface Beliefset {
    description?: string;
    subBeliefsetPtrs?: string[];
    unsupportedMachinePtrs?: string[];
    unsupportedPropositionPtrs?: string[];
    assignablePtr?: string;
    citations?: Citation[];
    contributor?: User;
    ephemeralPtr?: string;
    indexable?: boolean;
    names?: string[];
    notPermanentPtr?: string;
    permanentPtr?: string;
    tags?: string[];
}
export interface Dataset {
    bannerUrl?: string;
    customHomeArticle?: boolean;
    description?: string;
    iconUrl?: string;
    licenses?: License[];
    name?: string;
    openAcls?: AccessType[];
    subscribedDatasets?: string[];
    tags?: string[];
}
export interface License {
    licenseText?: string;
    licenseType?: LicenseType;
    linkToLicense?: string;
}
export declare enum LicenseType {
    Cc0 = "CC0",
    CcBy = "CC_BY",
    CcByNc = "CC_BY_NC",
    CcByNcNd = "CC_BY_NC_ND",
    CcByNcSa = "CC_BY_NC_SA",
    CcByNd = "CC_BY_ND",
    CcBySa = "CC_BY_SA",
    GNUGPL = "GNU_GPL",
    MIT = "MIT",
    Unknown = "UNKNOWN"
}
export declare enum AccessType {
    AddNewData = "ADD_NEW_DATA",
    ApproveDataUpdates = "APPROVE_DATA_UPDATES",
    ApproveUserUpdates = "APPROVE_USER_UPDATES",
    ApproveValidity = "APPROVE_VALIDITY",
    Comment = "COMMENT",
    DatasetPropertyUpdate = "DATASET_PROPERTY_UPDATE",
    EditDeleteData = "EDIT_DELETE_DATA",
    GlobalApproveValidity = "GLOBAL_APPROVE_VALIDITY",
    ModerateComments = "MODERATE_COMMENTS",
    ReadData = "READ_DATA",
    SuggestDataUpdates = "SUGGEST_DATA_UPDATES",
    SuggestUserUpdates = "SUGGEST_USER_UPDATES",
    Unknown = "UNKNOWN",
    UpdateUser = "UPDATE_USER"
}
export interface Machine {
    defaultLanguage?: Language;
    defaultLenientStatement?: string;
    defaultMaterializeDataset?: string;
    defaultStrictStatement?: string;
    description?: string;
    premiseMachines?: string[];
    premisePropositions?: string[];
    serverName?: string;
    assignablePtr?: string;
    citations?: Citation[];
    contributor?: User;
    ephemeralPtr?: string;
    indexable?: boolean;
    names?: string[];
    notPermanentPtr?: string;
    permanentPtr?: string;
    tags?: string[];
}
export interface Page {
    citations?: Citation[];
    contributor?: User;
    description?: string;
    pageId?: string;
    parentPageId?: string;
    sortHint?: number;
    title?: string;
}
export interface Project {
    abstractText?: string;
    description?: string;
    assignablePtr?: string;
    citations?: Citation[];
    contributor?: User;
    ephemeralPtr?: string;
    indexable?: boolean;
    names?: string[];
    notPermanentPtr?: string;
    permanentPtr?: string;
    tags?: string[];
}
export interface ProofRequest {
    fetchProof?: boolean;
    fetchUpdatedProposition?: boolean;
    machinePtr?: string;
    parseLenient?: boolean;
    proposition?: Proposition;
}
export interface Proposition {
    language?: Language;
    lookupTerms?: string[];
    metaLanguage?: MetaLanguage;
    negativeStatement?: string;
    remarks?: string;
    statement?: string;
    assignablePtr?: string;
    citations?: Citation[];
    contributor?: User;
    ephemeralPtr?: string;
    indexable?: boolean;
    names?: string[];
    notPermanentPtr?: string;
    permanentPtr?: string;
    tags?: string[];
}
export interface ProofResponse {
    existingPropositionPtr?: string;
    message?: string;
    proofArguments?: Argument[];
    proofPropositions?: Proposition[];
    resolvedProposition?: Proposition;
    truthValue?: TruthValue;
}
export declare enum TruthValue {
    Contradiction = "CONTRADICTION",
    False = "FALSE",
    True = "TRUE",
    Unknown = "UNKNOWN"
}
export interface Resource {
    assignablePtr?: string;
    citations?: Citation[];
    contributor?: User;
    ephemeralPtr?: string;
    indexable?: boolean;
    names?: string[];
    notPermanentPtr?: string;
    permanentPtr?: string;
    tags?: string[];
}
export interface ResourceValidity {
    globalValidity?: ValidityUpdate;
    localValidity?: ValidityUpdate;
}
export interface ValidityUpdate {
    justification?: string;
    updater?: User;
    validityStatus?: ValidityStatus;
}
export declare enum ValidityStatus {
    AutoApproved = "AUTO_APPROVED",
    MachineApproved = "MACHINE_APPROVED",
    MachineDenied = "MACHINE_DENIED",
    ManualApproved = "MANUAL_APPROVED",
    ManualDenied = "MANUAL_DENIED",
    RequestedApproval = "REQUESTED_APPROVAL",
    Unapproved = "UNAPPROVED",
    Unknown = "UNKNOWN"
}
export interface Term {
    alternatePhrases?: string[];
    definition?: string;
    language?: Language;
    lookupTerms?: string[];
    metaLanguage?: MetaLanguage;
    phrase?: string;
    primitive?: boolean;
    remarks?: string;
    assignablePtr?: string;
    citations?: Citation[];
    contributor?: User;
    ephemeralPtr?: string;
    indexable?: boolean;
    names?: string[];
    notPermanentPtr?: string;
    permanentPtr?: string;
    tags?: string[];
}
export declare class Convert {
    static toTypes(json: string): Types;
    static typesToJson(value: Types): string;
    static toArgument(json: string): Argument;
    static argumentToJson(value: Argument): string;
    static toCitation(json: string): Citation;
    static citationToJson(value: Citation): string;
    static toUser(json: string): User;
    static userToJson(value: User): string;
    static toArticle(json: string): Article;
    static articleToJson(value: Article): string;
    static toAuthor(json: string): Author;
    static authorToJson(value: Author): string;
    static toBeliefset(json: string): Beliefset;
    static beliefsetToJson(value: Beliefset): string;
    static toDataset(json: string): Dataset;
    static datasetToJson(value: Dataset): string;
    static toLicense(json: string): License;
    static licenseToJson(value: License): string;
    static toMachine(json: string): Machine;
    static machineToJson(value: Machine): string;
    static toPage(json: string): Page;
    static pageToJson(value: Page): string;
    static toProject(json: string): Project;
    static projectToJson(value: Project): string;
    static toProofRequest(json: string): ProofRequest;
    static proofRequestToJson(value: ProofRequest): string;
    static toProposition(json: string): Proposition;
    static propositionToJson(value: Proposition): string;
    static toProofResponse(json: string): ProofResponse;
    static proofResponseToJson(value: ProofResponse): string;
    static toResource(json: string): Resource;
    static resourceToJson(value: Resource): string;
    static toResourceValidity(json: string): ResourceValidity;
    static resourceValidityToJson(value: ResourceValidity): string;
    static toValidityUpdate(json: string): ValidityUpdate;
    static validityUpdateToJson(value: ValidityUpdate): string;
    static toTerm(json: string): Term;
    static termToJson(value: Term): string;
}
