"use strict";
// To parse this data:
//
//   import { Convert, Types } from "./file";
//
//   const types = Convert.toTypes(json);
//
// These functions will throw an error if the JSON doesn't
// match the expected interface, even if the JSON is valid.
Object.defineProperty(exports, "__esModule", { value: true });
exports.Convert = exports.ValidityStatus = exports.TruthValue = exports.AccessType = exports.LicenseType = exports.MetaLanguage = exports.Language = void 0;
var Language;
(function (Language) {
    Language["Informal"] = "INFORMAL";
    Language["MetamathSetMm"] = "METAMATH_SET_MM";
})(Language = exports.Language || (exports.Language = {}));
var MetaLanguage;
(function (MetaLanguage) {
    MetaLanguage["Informal"] = "INFORMAL";
    MetaLanguage["Metamath"] = "METAMATH";
})(MetaLanguage = exports.MetaLanguage || (exports.MetaLanguage = {}));
var LicenseType;
(function (LicenseType) {
    LicenseType["Cc0"] = "CC0";
    LicenseType["CcBy"] = "CC_BY";
    LicenseType["CcByNc"] = "CC_BY_NC";
    LicenseType["CcByNcNd"] = "CC_BY_NC_ND";
    LicenseType["CcByNcSa"] = "CC_BY_NC_SA";
    LicenseType["CcByNd"] = "CC_BY_ND";
    LicenseType["CcBySa"] = "CC_BY_SA";
    LicenseType["GNUGPL"] = "GNU_GPL";
    LicenseType["MIT"] = "MIT";
    LicenseType["Unknown"] = "UNKNOWN";
})(LicenseType = exports.LicenseType || (exports.LicenseType = {}));
var AccessType;
(function (AccessType) {
    AccessType["AddNewData"] = "ADD_NEW_DATA";
    AccessType["ApproveDataUpdates"] = "APPROVE_DATA_UPDATES";
    AccessType["ApproveUserUpdates"] = "APPROVE_USER_UPDATES";
    AccessType["ApproveValidity"] = "APPROVE_VALIDITY";
    AccessType["Comment"] = "COMMENT";
    AccessType["DatasetPropertyUpdate"] = "DATASET_PROPERTY_UPDATE";
    AccessType["EditDeleteData"] = "EDIT_DELETE_DATA";
    AccessType["GlobalApproveValidity"] = "GLOBAL_APPROVE_VALIDITY";
    AccessType["ModerateComments"] = "MODERATE_COMMENTS";
    AccessType["ReadData"] = "READ_DATA";
    AccessType["SuggestDataUpdates"] = "SUGGEST_DATA_UPDATES";
    AccessType["SuggestUserUpdates"] = "SUGGEST_USER_UPDATES";
    AccessType["Unknown"] = "UNKNOWN";
    AccessType["UpdateUser"] = "UPDATE_USER";
})(AccessType = exports.AccessType || (exports.AccessType = {}));
var TruthValue;
(function (TruthValue) {
    TruthValue["Contradiction"] = "CONTRADICTION";
    TruthValue["False"] = "FALSE";
    TruthValue["True"] = "TRUE";
    TruthValue["Unknown"] = "UNKNOWN";
})(TruthValue = exports.TruthValue || (exports.TruthValue = {}));
var ValidityStatus;
(function (ValidityStatus) {
    ValidityStatus["AutoApproved"] = "AUTO_APPROVED";
    ValidityStatus["MachineApproved"] = "MACHINE_APPROVED";
    ValidityStatus["MachineDenied"] = "MACHINE_DENIED";
    ValidityStatus["ManualApproved"] = "MANUAL_APPROVED";
    ValidityStatus["ManualDenied"] = "MANUAL_DENIED";
    ValidityStatus["RequestedApproval"] = "REQUESTED_APPROVAL";
    ValidityStatus["Unapproved"] = "UNAPPROVED";
    ValidityStatus["Unknown"] = "UNKNOWN";
})(ValidityStatus = exports.ValidityStatus || (exports.ValidityStatus = {}));
// Converts JSON strings to/from your types
// and asserts the results of JSON.parse at runtime
class Convert {
    static toTypes(json) {
        return cast(JSON.parse(json), r("Types"));
    }
    static typesToJson(value) {
        return JSON.stringify(uncast(value, r("Types")), null, 2);
    }
    static toArgument(json) {
        return cast(JSON.parse(json), r("Argument"));
    }
    static argumentToJson(value) {
        return JSON.stringify(uncast(value, r("Argument")), null, 2);
    }
    static toCitation(json) {
        return cast(JSON.parse(json), r("Citation"));
    }
    static citationToJson(value) {
        return JSON.stringify(uncast(value, r("Citation")), null, 2);
    }
    static toUser(json) {
        return cast(JSON.parse(json), r("User"));
    }
    static userToJson(value) {
        return JSON.stringify(uncast(value, r("User")), null, 2);
    }
    static toArticle(json) {
        return cast(JSON.parse(json), r("Article"));
    }
    static articleToJson(value) {
        return JSON.stringify(uncast(value, r("Article")), null, 2);
    }
    static toAuthor(json) {
        return cast(JSON.parse(json), r("Author"));
    }
    static authorToJson(value) {
        return JSON.stringify(uncast(value, r("Author")), null, 2);
    }
    static toBeliefset(json) {
        return cast(JSON.parse(json), r("Beliefset"));
    }
    static beliefsetToJson(value) {
        return JSON.stringify(uncast(value, r("Beliefset")), null, 2);
    }
    static toDataset(json) {
        return cast(JSON.parse(json), r("Dataset"));
    }
    static datasetToJson(value) {
        return JSON.stringify(uncast(value, r("Dataset")), null, 2);
    }
    static toLicense(json) {
        return cast(JSON.parse(json), r("License"));
    }
    static licenseToJson(value) {
        return JSON.stringify(uncast(value, r("License")), null, 2);
    }
    static toMachine(json) {
        return cast(JSON.parse(json), r("Machine"));
    }
    static machineToJson(value) {
        return JSON.stringify(uncast(value, r("Machine")), null, 2);
    }
    static toPage(json) {
        return cast(JSON.parse(json), r("Page"));
    }
    static pageToJson(value) {
        return JSON.stringify(uncast(value, r("Page")), null, 2);
    }
    static toProject(json) {
        return cast(JSON.parse(json), r("Project"));
    }
    static projectToJson(value) {
        return JSON.stringify(uncast(value, r("Project")), null, 2);
    }
    static toProofRequest(json) {
        return cast(JSON.parse(json), r("ProofRequest"));
    }
    static proofRequestToJson(value) {
        return JSON.stringify(uncast(value, r("ProofRequest")), null, 2);
    }
    static toProposition(json) {
        return cast(JSON.parse(json), r("Proposition"));
    }
    static propositionToJson(value) {
        return JSON.stringify(uncast(value, r("Proposition")), null, 2);
    }
    static toProofResponse(json) {
        return cast(JSON.parse(json), r("ProofResponse"));
    }
    static proofResponseToJson(value) {
        return JSON.stringify(uncast(value, r("ProofResponse")), null, 2);
    }
    static toResource(json) {
        return cast(JSON.parse(json), r("Resource"));
    }
    static resourceToJson(value) {
        return JSON.stringify(uncast(value, r("Resource")), null, 2);
    }
    static toResourceValidity(json) {
        return cast(JSON.parse(json), r("ResourceValidity"));
    }
    static resourceValidityToJson(value) {
        return JSON.stringify(uncast(value, r("ResourceValidity")), null, 2);
    }
    static toValidityUpdate(json) {
        return cast(JSON.parse(json), r("ValidityUpdate"));
    }
    static validityUpdateToJson(value) {
        return JSON.stringify(uncast(value, r("ValidityUpdate")), null, 2);
    }
    static toTerm(json) {
        return cast(JSON.parse(json), r("Term"));
    }
    static termToJson(value) {
        return JSON.stringify(uncast(value, r("Term")), null, 2);
    }
}
exports.Convert = Convert;
function invalidValue(typ, val, key = '') {
    if (key) {
        throw Error(`Invalid value for key "${key}". Expected type ${JSON.stringify(typ)} but got ${JSON.stringify(val)}`);
    }
    throw Error(`Invalid value ${JSON.stringify(val)} for type ${JSON.stringify(typ)}`);
}
function jsonToJSProps(typ) {
    if (typ.jsonToJS === undefined) {
        const map = {};
        typ.props.forEach((p) => map[p.json] = { key: p.js, typ: p.typ });
        typ.jsonToJS = map;
    }
    return typ.jsonToJS;
}
function jsToJSONProps(typ) {
    if (typ.jsToJSON === undefined) {
        const map = {};
        typ.props.forEach((p) => map[p.js] = { key: p.json, typ: p.typ });
        typ.jsToJSON = map;
    }
    return typ.jsToJSON;
}
function transform(val, typ, getProps, key = '') {
    function transformPrimitive(typ, val) {
        if (typeof typ === typeof val)
            return val;
        return invalidValue(typ, val, key);
    }
    function transformUnion(typs, val) {
        // val must validate against one typ in typs
        const l = typs.length;
        for (let i = 0; i < l; i++) {
            const typ = typs[i];
            try {
                return transform(val, typ, getProps);
            }
            catch (_) { }
        }
        return invalidValue(typs, val);
    }
    function transformEnum(cases, val) {
        if (cases.indexOf(val) !== -1)
            return val;
        return invalidValue(cases, val);
    }
    function transformArray(typ, val) {
        // val must be an array with no invalid elements
        if (!Array.isArray(val))
            return invalidValue("array", val);
        return val.map(el => transform(el, typ, getProps));
    }
    function transformDate(val) {
        if (val === null) {
            return null;
        }
        const d = new Date(val);
        if (isNaN(d.valueOf())) {
            return invalidValue("Date", val);
        }
        return d;
    }
    function transformObject(props, additional, val) {
        if (val === null || typeof val !== "object" || Array.isArray(val)) {
            return invalidValue("object", val);
        }
        const result = {};
        Object.getOwnPropertyNames(props).forEach(key => {
            const prop = props[key];
            const v = Object.prototype.hasOwnProperty.call(val, key) ? val[key] : undefined;
            result[prop.key] = transform(v, prop.typ, getProps, prop.key);
        });
        Object.getOwnPropertyNames(val).forEach(key => {
            if (!Object.prototype.hasOwnProperty.call(props, key)) {
                result[key] = transform(val[key], additional, getProps, key);
            }
        });
        return result;
    }
    if (typ === "any")
        return val;
    if (typ === null) {
        if (val === null)
            return val;
        return invalidValue(typ, val);
    }
    if (typ === false)
        return invalidValue(typ, val);
    while (typeof typ === "object" && typ.ref !== undefined) {
        typ = typeMap[typ.ref];
    }
    if (Array.isArray(typ))
        return transformEnum(typ, val);
    if (typeof typ === "object") {
        return typ.hasOwnProperty("unionMembers") ? transformUnion(typ.unionMembers, val)
            : typ.hasOwnProperty("arrayItems") ? transformArray(typ.arrayItems, val)
                : typ.hasOwnProperty("props") ? transformObject(getProps(typ), typ.additional, val)
                    : invalidValue(typ, val);
    }
    // Numbers can be parsed by Date but shouldn't be.
    if (typ === Date && typeof val !== "number")
        return transformDate(val);
    return transformPrimitive(typ, val);
}
function cast(val, typ) {
    return transform(val, typ, jsonToJSProps);
}
function uncast(val, typ) {
    return transform(val, typ, jsToJSONProps);
}
function a(typ) {
    return { arrayItems: typ };
}
function u(...typs) {
    return { unionMembers: typs };
}
function o(props, additional) {
    return { props, additional };
}
function m(additional) {
    return { props: [], additional };
}
function r(name) {
    return { ref: name };
}
const typeMap = {
    "Types": o([
        { json: "argument", js: "argument", typ: u(undefined, r("Argument")) },
        { json: "article", js: "article", typ: u(undefined, r("Article")) },
        { json: "beliefset", js: "beliefset", typ: u(undefined, r("Beliefset")) },
        { json: "dataset", js: "dataset", typ: u(undefined, r("Dataset")) },
        { json: "machine", js: "machine", typ: u(undefined, r("Machine")) },
        { json: "page", js: "page", typ: u(undefined, r("Page")) },
        { json: "project", js: "project", typ: u(undefined, r("Project")) },
        { json: "proofRequest", js: "proofRequest", typ: u(undefined, r("ProofRequest")) },
        { json: "proofResponse", js: "proofResponse", typ: u(undefined, r("ProofResponse")) },
        { json: "proposition", js: "proposition", typ: u(undefined, r("Proposition")) },
        { json: "resource", js: "resource", typ: u(undefined, r("Resource")) },
        { json: "resourceValidity", js: "resourceValidity", typ: u(undefined, r("ResourceValidity")) },
        { json: "term", js: "term", typ: u(undefined, r("Term")) },
    ], "any"),
    "Argument": o([
        { json: "argumentText", js: "argumentText", typ: u(undefined, "") },
        { json: "conclusion", js: "conclusion", typ: u(undefined, "") },
        { json: "language", js: "language", typ: u(undefined, r("Language")) },
        { json: "lookupTerms", js: "lookupTerms", typ: u(undefined, a("")) },
        { json: "metaLanguage", js: "metaLanguage", typ: u(undefined, r("MetaLanguage")) },
        { json: "premiseMachine", js: "premiseMachine", typ: u(undefined, "") },
        { json: "premises", js: "premises", typ: u(undefined, a("")) },
        { json: "assignablePtr", js: "assignablePtr", typ: u(undefined, "") },
        { json: "citations", js: "citations", typ: u(undefined, a(r("Citation"))) },
        { json: "contributor", js: "contributor", typ: u(undefined, r("User")) },
        { json: "ephemeralPtr", js: "ephemeralPtr", typ: u(undefined, "") },
        { json: "indexable", js: "indexable", typ: u(undefined, true) },
        { json: "names", js: "names", typ: u(undefined, a("")) },
        { json: "notPermanentPtr", js: "notPermanentPtr", typ: u(undefined, "") },
        { json: "permanentPtr", js: "permanentPtr", typ: u(undefined, "") },
        { json: "tags", js: "tags", typ: u(undefined, a("")) },
    ], "any"),
    "Citation": o([
        { json: "textCitation", js: "textCitation", typ: u(undefined, "") },
    ], false),
    "User": o([
        { json: "handle", js: "handle", typ: u(undefined, "") },
        { json: "userEmail", js: "userEmail", typ: u(undefined, "") },
        { json: "userLink", js: "userLink", typ: u(undefined, "") },
        { json: "userName", js: "userName", typ: u(undefined, "") },
        { json: "userPic", js: "userPic", typ: u(undefined, "") },
    ], false),
    "Article": o([
        { json: "abstractText", js: "abstractText", typ: u(undefined, "") },
        { json: "authors", js: "authors", typ: u(undefined, a(r("Author"))) },
        { json: "beliefset", js: "beliefset", typ: u(undefined, "") },
        { json: "content", js: "content", typ: u(undefined, "") },
        { json: "title", js: "title", typ: u(undefined, "") },
        { json: "assignablePtr", js: "assignablePtr", typ: u(undefined, "") },
        { json: "citations", js: "citations", typ: u(undefined, a(r("Citation"))) },
        { json: "contributor", js: "contributor", typ: u(undefined, r("User")) },
        { json: "ephemeralPtr", js: "ephemeralPtr", typ: u(undefined, "") },
        { json: "indexable", js: "indexable", typ: u(undefined, true) },
        { json: "names", js: "names", typ: u(undefined, a("")) },
        { json: "notPermanentPtr", js: "notPermanentPtr", typ: u(undefined, "") },
        { json: "permanentPtr", js: "permanentPtr", typ: u(undefined, "") },
        { json: "tags", js: "tags", typ: u(undefined, a("")) },
    ], "any"),
    "Author": o([
        { json: "user", js: "user", typ: u(undefined, r("User")) },
    ], false),
    "Beliefset": o([
        { json: "description", js: "description", typ: u(undefined, "") },
        { json: "subBeliefsetPtrs", js: "subBeliefsetPtrs", typ: u(undefined, a("")) },
        { json: "unsupportedMachinePtrs", js: "unsupportedMachinePtrs", typ: u(undefined, a("")) },
        { json: "unsupportedPropositionPtrs", js: "unsupportedPropositionPtrs", typ: u(undefined, a("")) },
        { json: "assignablePtr", js: "assignablePtr", typ: u(undefined, "") },
        { json: "citations", js: "citations", typ: u(undefined, a(r("Citation"))) },
        { json: "contributor", js: "contributor", typ: u(undefined, r("User")) },
        { json: "ephemeralPtr", js: "ephemeralPtr", typ: u(undefined, "") },
        { json: "indexable", js: "indexable", typ: u(undefined, true) },
        { json: "names", js: "names", typ: u(undefined, a("")) },
        { json: "notPermanentPtr", js: "notPermanentPtr", typ: u(undefined, "") },
        { json: "permanentPtr", js: "permanentPtr", typ: u(undefined, "") },
        { json: "tags", js: "tags", typ: u(undefined, a("")) },
    ], "any"),
    "Dataset": o([
        { json: "bannerUrl", js: "bannerUrl", typ: u(undefined, "") },
        { json: "customHomeArticle", js: "customHomeArticle", typ: u(undefined, true) },
        { json: "description", js: "description", typ: u(undefined, "") },
        { json: "iconUrl", js: "iconUrl", typ: u(undefined, "") },
        { json: "licenses", js: "licenses", typ: u(undefined, a(r("License"))) },
        { json: "name", js: "name", typ: u(undefined, "") },
        { json: "openAcls", js: "openAcls", typ: u(undefined, a(r("AccessType"))) },
        { json: "subscribedDatasets", js: "subscribedDatasets", typ: u(undefined, a("")) },
        { json: "tags", js: "tags", typ: u(undefined, a("")) },
    ], false),
    "License": o([
        { json: "licenseText", js: "licenseText", typ: u(undefined, "") },
        { json: "licenseType", js: "licenseType", typ: u(undefined, r("LicenseType")) },
        { json: "linkToLicense", js: "linkToLicense", typ: u(undefined, "") },
    ], false),
    "Machine": o([
        { json: "defaultLanguage", js: "defaultLanguage", typ: u(undefined, r("Language")) },
        { json: "defaultLenientStatement", js: "defaultLenientStatement", typ: u(undefined, "") },
        { json: "defaultMaterializeDataset", js: "defaultMaterializeDataset", typ: u(undefined, "") },
        { json: "defaultStrictStatement", js: "defaultStrictStatement", typ: u(undefined, "") },
        { json: "description", js: "description", typ: u(undefined, "") },
        { json: "premiseMachines", js: "premiseMachines", typ: u(undefined, a("")) },
        { json: "premisePropositions", js: "premisePropositions", typ: u(undefined, a("")) },
        { json: "serverName", js: "serverName", typ: u(undefined, "") },
        { json: "assignablePtr", js: "assignablePtr", typ: u(undefined, "") },
        { json: "citations", js: "citations", typ: u(undefined, a(r("Citation"))) },
        { json: "contributor", js: "contributor", typ: u(undefined, r("User")) },
        { json: "ephemeralPtr", js: "ephemeralPtr", typ: u(undefined, "") },
        { json: "indexable", js: "indexable", typ: u(undefined, true) },
        { json: "names", js: "names", typ: u(undefined, a("")) },
        { json: "notPermanentPtr", js: "notPermanentPtr", typ: u(undefined, "") },
        { json: "permanentPtr", js: "permanentPtr", typ: u(undefined, "") },
        { json: "tags", js: "tags", typ: u(undefined, a("")) },
    ], "any"),
    "Page": o([
        { json: "citations", js: "citations", typ: u(undefined, a(r("Citation"))) },
        { json: "contributor", js: "contributor", typ: u(undefined, r("User")) },
        { json: "description", js: "description", typ: u(undefined, "") },
        { json: "pageId", js: "pageId", typ: u(undefined, "") },
        { json: "parentPageId", js: "parentPageId", typ: u(undefined, "") },
        { json: "sortHint", js: "sortHint", typ: u(undefined, 3.14) },
        { json: "title", js: "title", typ: u(undefined, "") },
    ], "any"),
    "Project": o([
        { json: "abstractText", js: "abstractText", typ: u(undefined, "") },
        { json: "description", js: "description", typ: u(undefined, "") },
        { json: "assignablePtr", js: "assignablePtr", typ: u(undefined, "") },
        { json: "citations", js: "citations", typ: u(undefined, a(r("Citation"))) },
        { json: "contributor", js: "contributor", typ: u(undefined, r("User")) },
        { json: "ephemeralPtr", js: "ephemeralPtr", typ: u(undefined, "") },
        { json: "indexable", js: "indexable", typ: u(undefined, true) },
        { json: "names", js: "names", typ: u(undefined, a("")) },
        { json: "notPermanentPtr", js: "notPermanentPtr", typ: u(undefined, "") },
        { json: "permanentPtr", js: "permanentPtr", typ: u(undefined, "") },
        { json: "tags", js: "tags", typ: u(undefined, a("")) },
    ], "any"),
    "ProofRequest": o([
        { json: "fetchProof", js: "fetchProof", typ: u(undefined, true) },
        { json: "fetchUpdatedProposition", js: "fetchUpdatedProposition", typ: u(undefined, true) },
        { json: "machinePtr", js: "machinePtr", typ: u(undefined, "") },
        { json: "parseLenient", js: "parseLenient", typ: u(undefined, true) },
        { json: "proposition", js: "proposition", typ: u(undefined, r("Proposition")) },
    ], false),
    "Proposition": o([
        { json: "language", js: "language", typ: u(undefined, r("Language")) },
        { json: "lookupTerms", js: "lookupTerms", typ: u(undefined, a("")) },
        { json: "metaLanguage", js: "metaLanguage", typ: u(undefined, r("MetaLanguage")) },
        { json: "negativeStatement", js: "negativeStatement", typ: u(undefined, "") },
        { json: "remarks", js: "remarks", typ: u(undefined, "") },
        { json: "statement", js: "statement", typ: u(undefined, "") },
        { json: "assignablePtr", js: "assignablePtr", typ: u(undefined, "") },
        { json: "citations", js: "citations", typ: u(undefined, a(r("Citation"))) },
        { json: "contributor", js: "contributor", typ: u(undefined, r("User")) },
        { json: "ephemeralPtr", js: "ephemeralPtr", typ: u(undefined, "") },
        { json: "indexable", js: "indexable", typ: u(undefined, true) },
        { json: "names", js: "names", typ: u(undefined, a("")) },
        { json: "notPermanentPtr", js: "notPermanentPtr", typ: u(undefined, "") },
        { json: "permanentPtr", js: "permanentPtr", typ: u(undefined, "") },
        { json: "tags", js: "tags", typ: u(undefined, a("")) },
    ], "any"),
    "ProofResponse": o([
        { json: "existingPropositionPtr", js: "existingPropositionPtr", typ: u(undefined, "") },
        { json: "message", js: "message", typ: u(undefined, "") },
        { json: "proofArguments", js: "proofArguments", typ: u(undefined, a(r("Argument"))) },
        { json: "proofPropositions", js: "proofPropositions", typ: u(undefined, a(r("Proposition"))) },
        { json: "resolvedProposition", js: "resolvedProposition", typ: u(undefined, r("Proposition")) },
        { json: "truthValue", js: "truthValue", typ: u(undefined, r("TruthValue")) },
    ], false),
    "Resource": o([
        { json: "assignablePtr", js: "assignablePtr", typ: u(undefined, "") },
        { json: "citations", js: "citations", typ: u(undefined, a(r("Citation"))) },
        { json: "contributor", js: "contributor", typ: u(undefined, r("User")) },
        { json: "ephemeralPtr", js: "ephemeralPtr", typ: u(undefined, "") },
        { json: "indexable", js: "indexable", typ: u(undefined, true) },
        { json: "names", js: "names", typ: u(undefined, a("")) },
        { json: "notPermanentPtr", js: "notPermanentPtr", typ: u(undefined, "") },
        { json: "permanentPtr", js: "permanentPtr", typ: u(undefined, "") },
        { json: "tags", js: "tags", typ: u(undefined, a("")) },
    ], "any"),
    "ResourceValidity": o([
        { json: "globalValidity", js: "globalValidity", typ: u(undefined, r("ValidityUpdate")) },
        { json: "localValidity", js: "localValidity", typ: u(undefined, r("ValidityUpdate")) },
    ], false),
    "ValidityUpdate": o([
        { json: "justification", js: "justification", typ: u(undefined, "") },
        { json: "updater", js: "updater", typ: u(undefined, r("User")) },
        { json: "validityStatus", js: "validityStatus", typ: u(undefined, r("ValidityStatus")) },
    ], false),
    "Term": o([
        { json: "alternatePhrases", js: "alternatePhrases", typ: u(undefined, a("")) },
        { json: "definition", js: "definition", typ: u(undefined, "") },
        { json: "language", js: "language", typ: u(undefined, r("Language")) },
        { json: "lookupTerms", js: "lookupTerms", typ: u(undefined, a("")) },
        { json: "metaLanguage", js: "metaLanguage", typ: u(undefined, r("MetaLanguage")) },
        { json: "phrase", js: "phrase", typ: u(undefined, "") },
        { json: "primitive", js: "primitive", typ: u(undefined, true) },
        { json: "remarks", js: "remarks", typ: u(undefined, "") },
        { json: "assignablePtr", js: "assignablePtr", typ: u(undefined, "") },
        { json: "citations", js: "citations", typ: u(undefined, a(r("Citation"))) },
        { json: "contributor", js: "contributor", typ: u(undefined, r("User")) },
        { json: "ephemeralPtr", js: "ephemeralPtr", typ: u(undefined, "") },
        { json: "indexable", js: "indexable", typ: u(undefined, true) },
        { json: "names", js: "names", typ: u(undefined, a("")) },
        { json: "notPermanentPtr", js: "notPermanentPtr", typ: u(undefined, "") },
        { json: "permanentPtr", js: "permanentPtr", typ: u(undefined, "") },
        { json: "tags", js: "tags", typ: u(undefined, a("")) },
    ], "any"),
    "Language": [
        "INFORMAL",
        "METAMATH_SET_MM",
    ],
    "MetaLanguage": [
        "INFORMAL",
        "METAMATH",
    ],
    "LicenseType": [
        "CC0",
        "CC_BY",
        "CC_BY_NC",
        "CC_BY_NC_ND",
        "CC_BY_NC_SA",
        "CC_BY_ND",
        "CC_BY_SA",
        "GNU_GPL",
        "MIT",
        "UNKNOWN",
    ],
    "AccessType": [
        "ADD_NEW_DATA",
        "APPROVE_DATA_UPDATES",
        "APPROVE_USER_UPDATES",
        "APPROVE_VALIDITY",
        "COMMENT",
        "DATASET_PROPERTY_UPDATE",
        "EDIT_DELETE_DATA",
        "GLOBAL_APPROVE_VALIDITY",
        "MODERATE_COMMENTS",
        "READ_DATA",
        "SUGGEST_DATA_UPDATES",
        "SUGGEST_USER_UPDATES",
        "UNKNOWN",
        "UPDATE_USER",
    ],
    "TruthValue": [
        "CONTRADICTION",
        "FALSE",
        "TRUE",
        "UNKNOWN",
    ],
    "ValidityStatus": [
        "AUTO_APPROVED",
        "MACHINE_APPROVED",
        "MACHINE_DENIED",
        "MANUAL_APPROVED",
        "MANUAL_DENIED",
        "REQUESTED_APPROVAL",
        "UNAPPROVED",
        "UNKNOWN",
    ],
};
